SqlCipherKeyring

Struct SqlCipherKeyring 

pub struct SqlCipherKeyring { /* private fields */ }
Available on crate feature file only.

Implementations

Source

impl SqlCipherKeyring

pub fn rekey(&self, new_params: &ConnectionParams) -> Result<()>

Re-encrypt the entire database with a new key derived from new_params.

The keyring must already be open (authenticated with the current key). After a successful rekey the current connection uses the new key; any future opens must use new_params.

pub fn with_params( connection: &ConnectionParams, path: Option<PathBuf>, ) -> Result<Self>

Create a new keyring with the connection params