pub struct SqlCipherKeyring { /* private fields */ }Available on crate feature
file only.Implementations
Sourceimpl SqlCipherKeyring
impl SqlCipherKeyring
Sourcepub fn rekey(&self, new_params: &ConnectionParams) -> Result<()>
pub fn rekey(&self, new_params: &ConnectionParams) -> Result<()>
Re-encrypt the entire database with a new key derived from new_params.
The keyring must already be open (authenticated with the current key).
After a successful rekey the current connection uses the new key;
any future opens must use new_params.
Sourcepub fn with_params(
connection: &ConnectionParams,
path: Option<PathBuf>,
) -> Result<Self>
pub fn with_params( connection: &ConnectionParams, path: Option<PathBuf>, ) -> Result<Self>
Create a new keyring with the connection params